@@ -1,12 +1,19 @@
+"""ZnTrack - Create, visualize, run & benchmark DVC pipelines in Python.
+
+GitHub: https://github.com/zincware/ZnTrack
+"""
+import importlib.metadata
 import logging
 import sys
 
 import znjson
 
+from zntrack import utils
 from zntrack.core.base import Node
 from zntrack.core.functions.decorator import NodeConfig, nodify
 from zntrack.interface.base import DVCInterface
 from zntrack.project.zntrack_project import ZnTrackProject
+from zntrack.utils import exceptions, nwd
 from zntrack.utils.config import config
 from zntrack.utils.serializer import (
     MethodConverter,
@@ -16,7 +23,7 @@ from zntrack.utils.serializer import (
 from zntrack.zn.dependencies import getdeps
 
 # register converters
-znjson.register([ZnTrackTypeConverter, MethodConverter, NodeAttributeConverter])
+znjson.config.register([ZnTrackTypeConverter, MethodConverter, NodeAttributeConverter])
 
 __all__ = [
     Node.__name__,
@@ -26,9 +33,12 @@ __all__ = [
     nodify.__name__,
     NodeConfig.__name__,
     "getdeps",
+    "utils",
+    "exceptions",
+    "nwd",
 ]
 
-__version__ = "0.4.1"
+__version__ = importlib.metadata.version("zntrack")
 
 logger = logging.getLogger(__name__)
 logger.setLevel(config.log_level)
