@@ -139,7 +139,7 @@ def prepare_dvc_script(
     nb_name,
     module,
     func_or_cls,
-    call_args,
+    call_args=None,
 ) -> list:
     """Prepare the dvc cmd to be called by subprocess.
 
@@ -172,8 +172,10 @@ def prepare_dvc_script(
     if nb_name is not None:
         script += ["--deps", utils.module_to_path(module).as_posix()]
 
-    import_str = f"""{utils.config.interpreter} -c "from {module} import """
-    import_str += f"""{func_or_cls}; {func_or_cls}{call_args}" """
+    import_str = f"zntrack run {module}.{func_or_cls}"
+    if call_args is not None:
+        import_str += f" {call_args}"
+
     script += [import_str]
     log.debug(f"dvc script: {' '.join([str(x) for x in script])}")
     return script
